@@ -61,7 +61,7 @@ import org.codehaus.plexus.util.FileUtils;
  * 
  * @author Jurgen Lust
  * @author Mark Hobson <markhobson@gmail.com>
- * @version $Id: AbstractRunMojo.java 12154 2010-05-02 21:33:39Z olamy $
+ * @version $Id: AbstractRunMojo.java 12745 2010-10-01 09:04:32Z olamy $
  */
 public abstract class AbstractRunMojo
     extends AbstractI18NMojo
@@ -187,6 +187,7 @@ public abstract class AbstractRunMojo
      * @required
      * @since 1.0
      */
+    @SuppressWarnings("rawtypes")
     private List pluginArtifacts;
    
     /**
@@ -195,6 +196,21 @@ public abstract class AbstractRunMojo
      * @parameter expression="${tomcat.ignorePackaging}" default-value="false"
      */
     private boolean ignorePackaging;
+
+    /**
+     * Override the default keystoreFile for the HTTPS connector (if enabled)
+     * @since 1.1
+     * @parameter
+     */
+    private String keystoreFile;
+
+    /**
+     * Override the default keystorePass for the HTTPS connector (if enabled)
+     * @since 1.1
+     * @parameter
+     */
+    private String keystorePass;
+
     
     // ----------------------------------------------------------------------
     // Fields
@@ -313,6 +329,7 @@ public abstract class AbstractRunMojo
         {
             return new WebappLoader( getTomcatClassLoader() );
         }
+                
         return new WebappLoader( Thread.currentThread().getContextClassLoader() );
 
     }
@@ -524,6 +541,14 @@ public abstract class AbstractRunMojo
                 if ( httpsPort > 0 )
                 {
                     Connector httpsConnector = container.createConnector( (InetAddress) null, httpsPort, true );
+                    if ( keystoreFile!=null)
+                    {
+                        httpsConnector.setAttribute("keystoreFile", keystoreFile);
+                    }
+                    if ( keystorePass!=null)
+                    {
+                        httpsConnector.setAttribute("keystorePass", keystorePass);
+                    }
                     container.addConnector( httpsConnector );
                     
                 }
@@ -532,16 +557,7 @@ public abstract class AbstractRunMojo
             // start server
             container.start();
 
-            // add shutdown hook to stop server
-            Runtime.getRuntime().addShutdownHook( new Thread()
-            {
-                @Override
-                public void run()
-                {
-                    stopContainer();
-                }
-            } );
-
+            EmbeddedRegistry.getInstance().register(container);
         }
         finally
         {
@@ -561,7 +577,8 @@ public abstract class AbstractRunMojo
             ClassWorld world = new ClassWorld();
             ClassRealm root = world.newRealm( "tomcat", Thread.currentThread().getContextClassLoader() );
 
-            for ( Iterator i = pluginArtifacts.iterator(); i.hasNext(); )
+            for ( @SuppressWarnings("rawtypes")
+            Iterator i = pluginArtifacts.iterator(); i.hasNext(); )
             {
                 Artifact pluginArtifact = (Artifact) i.next();
                 if ( "org.apache.tomcat".equals( pluginArtifact.getGroupId() ) )
@@ -610,24 +627,7 @@ public abstract class AbstractRunMojo
             }
         }
     }
-
-    /**
-     * Stops the embedded Tomcat server.
-     */
-    private void stopContainer()
-    {
-        try
-        {
-            if ( container != null )
-            {
-                container.stop();
-            }
-        }
-        catch ( LifecycleException exception )
-        {
-            getLog().warn( getMessage( "AbstractRunMojo.cannotStop" ), exception );
-        }
-    }
+    
 
     /**
      * Set the SystemProperties from the configuration.
@@ -670,6 +670,7 @@ public abstract class AbstractRunMojo
         List<Context> contexts = new ArrayList<Context>();
 
         ScopeArtifactFilter filter = new ScopeArtifactFilter( "tomcat" );
+        @SuppressWarnings("unchecked")
         Set<Artifact> artifacts = project.getArtifacts();
         for ( Artifact artifact : artifacts )
         {
@@ -711,7 +712,7 @@ public abstract class AbstractRunMojo
                     }
                 }
                 WebappLoader webappLoader = new WebappLoader( Thread.currentThread().getContextClassLoader() );
-                Context context = container.createContext( artifact.getArtifactId(), artifactWarDir.getAbsolutePath() );
+                Context context = container.createContext( "/" + artifact.getArtifactId(), artifactWarDir.getAbsolutePath() );
                 context.setLoader( webappLoader );
                 context.setConfigFile( getContextFile().getAbsolutePath() );
                 contexts.add( context );
